BFGraph: myInt Class Reference

BFGraph

Public Member Functions | Data Fields
myInt Class Reference

Inherits CDBG_Data_t< myInt >.

## Public Member Functions
| myInt (int int_init=1)
void | join (const myInt &data, CompactedDBG< myInt > &cdbg)
void | split (const size_t pos, const size_t len, myInt &new_data, CompactedDBG< myInt > &cdbg) const

## Data Fields
int | Int

The documentation for this class was generated from the following file:

- src/BFGraph.cpp